==============================
varST(var ➡️ reStructuredText)
==============================

|PyPI version| |pre-commit.ci status| |GitHub Workflow Status| |Documentation Status|

Replace substitutions in rst files with variables.

Installation
------------

.. code:: bash

   $ pip install varst

Usage
-----

.. code:: bash

   $ varst [-i INPUT] [-o OUTPUT] [name=value ...]

License
-------

`MIT
License <https://github.com/junghoon-vans/varst/blob/main/LICENSE>`__


.. |PyPI version| image:: https://img.shields.io/pypi/v/varst
   :target: https://pypi.org/project/varst/
.. |pre-commit.ci status| image:: https://results.pre-commit.ci/badge/github/junghoon-vans/varst/main.svg
   :target: https://results.pre-commit.ci/latest/github/junghoon-vans/varst/main
.. |GitHub Workflow Status| image:: https://img.shields.io/github/workflow/status/junghoon-vans/varst/Upload%20Python%20Package
.. |Documentation Status| image:: https://readthedocs.org/projects/varst/badge/?version=latest
    :target: https://varst.readthedocs.io/en/latest/?badge=latest
